package com.bonus.zlpt.equip.service.impl;

import java.util.List;

import com.bonus.zlpt.equip.api.domain.FileInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.zlpt.equip.mapper.FileInfoMapper;
import com.bonus.zlpt.equip.service.IFileInfoService;

/**
 * 设备附件
Service业务层处理
 * 
 * @author xsheng
 * @date 2023-12-02
 */
@Service
public class FileInfoServiceImpl implements IFileInfoService 
{
    @Autowired
    private FileInfoMapper fileInfoMapper;

    /**
     * 查询设备附件

     * 
     * @param id 设备附件
主键
     * @return 设备附件

     */
    @Override
    public FileInfo selectFileInfoById(Long id)
    {
        return fileInfoMapper.selectFileInfoById(id);
    }

    /**
     * 查询设备附件
列表
     * 
     * @param fileInfo 设备附件

     * @return 设备附件

     */
    @Override
    public List<FileInfo> selectFileInfoList(FileInfo fileInfo)
    {
        return fileInfoMapper.selectFileInfoList(fileInfo);
    }

    /**
     * 新增设备附件

     * 
     * @param fileInfo 设备附件

     * @return 结果
     */
    @Override
    public int insertFileInfo(FileInfo fileInfo)
    {
        return fileInfoMapper.insertFileInfo(fileInfo);
    }

    /**
     * 修改设备附件

     * 
     * @param fileInfo 设备附件

     * @return 结果
     */
    @Override
    public int updateFileInfo(FileInfo fileInfo)
    {
        return fileInfoMapper.updateFileInfo(fileInfo);
    }

    /**
     * 批量删除设备附件

     * 
     * @param ids 需要删除的设备附件
主键
     * @return 结果
     */
    @Override
    public int deleteFileInfoByIds(Long[] ids)
    {
        return fileInfoMapper.deleteFileInfoByIds(ids);
    }

    /**
     * 删除设备附件
信息
     * 
     * @param id 设备附件
主键
     * @return 结果
     */
    @Override
    public int deleteFileInfoById(Long id)
    {
        return fileInfoMapper.deleteFileInfoById(id);
    }
}
